@@ -1,6 +1,6 @@
 package Net::Google::FederatedLogin;
 {
-  $Net::Google::FederatedLogin::VERSION = '0.7.2';
+  $Net::Google::FederatedLogin::VERSION = '0.8.0';
 }
 # ABSTRACT: Google Federated Login module - see http://code.google.com/apis/accounts/docs/OpenID.html
 
@@ -163,7 +163,7 @@ sub verify_auth {
             my $param = $_;
             my $val = $self->_get_param($param);
             $val = 'check_authentication' if $param eq 'openid.mode';
-            sprintf '%s=%s', uri_escape_utf8($param), uri_escape_utf8($val);
+            sprintf '%s=%s', uri_escape($param), uri_escape($val);
         } $self->_get_param;
     
     my $ua = $self->ua;
@@ -252,8 +252,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -262,7 +262,7 @@ Net::Google::FederatedLogin - Google Federated Login module - see http://code.go
 
 =head1 VERSION
 
-version 0.7.2
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -354,10 +354,9 @@ Glenn Fowler <cebjyre@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Glenn Fowler.
+This software is copyright (c) 2014 by Glenn Fowler.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
