@@ -1,6 +1,6 @@
 package Net::Google::FederatedLogin::Apps::Discoverer;
 {
-  $Net::Google::FederatedLogin::Apps::Discoverer::VERSION = '0.7.2';
+  $Net::Google::FederatedLogin::Apps::Discoverer::VERSION = '0.8.0';
 }
 # ABSTRACT: Find the OpenID endpoint for apps domain accounts
 
@@ -80,7 +80,7 @@ sub _get_user_discovery_url {
     my $self = shift;
     
     my $claimed_id = $self->claimed_id;
-    my $escaped_id = uri_escape_utf8($claimed_id);
+    my $escaped_id = uri_escape($claimed_id);
     
     my $intermediate_url = $self->_get_idp_discovery_url;
     
@@ -105,6 +105,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -113,7 +114,7 @@ Net::Google::FederatedLogin::Apps::Discoverer - Find the OpenID endpoint for app
 
 =head1 VERSION
 
-version 0.7.2
+version 0.8.0
 
 =head1 METHODS
 
@@ -129,10 +130,9 @@ Glenn Fowler <cebjyre@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Glenn Fowler.
+This software is copyright (c) 2014 by Glenn Fowler.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
